Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoshua Leung <aligorith@gmail.com>2009-06-20 08:02:49 +0400
committerJoshua Leung <aligorith@gmail.com>2009-06-20 08:02:49 +0400
commit6394ee9e8143988b2a0f9316fb7bca5dc78e6e53 (patch)
treeac6a3c209f6b8b7eca45742b2cf4b8ba0a0f38f7 /source/blender/editors/space_nla/nla_edit.c
parent6393e9b3ca7e40e95830d009020b0f106c00b529 (diff)
NLA SoC: Drawing + Editing Fixes
* Strips using the same action as the 'tweaking action' now get the error flag cleared after tweakmode is exited. (These strips draw with red shading) * The direction in which strips get played (as a result of the 'reversed' option) now gets indicated on strips by the direction of the arrow text printed on each strip * The active strip flag is now cleared after duplicating/splitting strips.
Diffstat (limited to 'source/blender/editors/space_nla/nla_edit.c')
-rw-r--r--source/blender/editors/space_nla/nla_edit.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/source/blender/editors/space_nla/nla_edit.c b/source/blender/editors/space_nla/nla_edit.c
index 8b7c6bb99c6..ebb0589a82d 100644
--- a/source/blender/editors/space_nla/nla_edit.c
+++ b/source/blender/editors/space_nla/nla_edit.c
@@ -492,8 +492,8 @@ static int nlaedit_duplicate_exec (bContext *C, wmOperator *op)
BKE_nlatrack_add_strip(track, nstrip);
}
- /* deselect the original */
- strip->flag &= ~NLASTRIP_FLAG_SELECT;
+ /* deselect the original and the active flag */
+ strip->flag &= ~(NLASTRIP_FLAG_SELECT|NLASTRIP_FLAG_ACTIVE);
done++;
}
@@ -666,6 +666,9 @@ static int nlaedit_split_exec (bContext *C, wmOperator *op)
strip->actend= midaframe;
nstrip->actstart= midaframe;
+
+ /* clear the active flag from the copy */
+ nstrip->flag &= ~NLASTRIP_FLAG_ACTIVE;
}
}
}